@@ -80,9 +80,9 @@ function get_udims( $width, $height ) {
  * @deprecated Use wp_category_checklist()
  * @see wp_category_checklist()
  *
- * @param unknown_type $default
- * @param unknown_type $parent
- * @param unknown_type $popular_ids
+ * @param int $default
+ * @param int $parent
+ * @param array $popular_ids
  */
 function dropdown_categories( $default = 0, $parent = 0, $popular_ids = array() ) {
 	_deprecated_function( __FUNCTION__, '2.6', 'wp_category_checklist()' );
@@ -98,7 +98,7 @@ function dropdown_categories( $default = 0, $parent = 0, $popular_ids = array()
  * @deprecated Use wp_link_category_checklist()
  * @see wp_link_category_checklist()
  *
- * @param unknown_type $default
+ * @param int $default
  */
 function dropdown_link_categories( $default = 0 ) {
 	_deprecated_function( __FUNCTION__, '2.6', 'wp_link_category_checklist()' );
@@ -130,12 +130,12 @@ function get_real_file_to_edit( $file ) {
  * @deprecated Use wp_dropdown_categories()
  * @see wp_dropdown_categories()
  *
- * @param unknown_type $currentcat
- * @param unknown_type $currentparent
- * @param unknown_type $parent
- * @param unknown_type $level
- * @param unknown_type $categories
- * @return unknown
+ * @param int $currentcat
+ * @param int $currentparent
+ * @param int $parent
+ * @param int $level
+ * @param array $categories
+ * @return bool|null
  */
 function wp_dropdown_cats( $currentcat = 0, $currentparent = 0, $parent = 0, $level = 0, $categories = 0 ) {
 	_deprecated_function( __FUNCTION__, '3.0', 'wp_dropdown_categories()' );
@@ -170,12 +170,11 @@ function wp_dropdown_cats( $currentcat = 0, $currentparent = 0, $parent = 0, $le
  * @param string $option_group A settings group name. Should correspond to a whitelisted option key name.
  * 	Default whitelisted option key names include "general," "discussion," and "reading," among others.
  * @param string $option_name The name of an option to sanitize and save.
- * @param unknown_type $sanitize_callback A callback function that sanitizes the option's value.
- * @return unknown
+ * @param callable $sanitize_callback A callback function that sanitizes the option's value.
  */
 function add_option_update_handler( $option_group, $option_name, $sanitize_callback = '' ) {
 	_deprecated_function( __FUNCTION__, '3.0', 'register_setting()' );
-	return register_setting( $option_group, $option_name, $sanitize_callback );
+	register_setting( $option_group, $option_name, $sanitize_callback );
 }
 
 /**
@@ -186,14 +185,13 @@ function add_option_update_handler( $option_group, $option_name, $sanitize_callb
  * @deprecated Use unregister_setting()
  * @see unregister_setting()
  *
- * @param unknown_type $option_group
- * @param unknown_type $option_name
- * @param unknown_type $sanitize_callback
- * @return unknown
+ * @param string $option_group
+ * @param string $option_name
+ * @param callable $sanitize_callback
  */
 function remove_option_update_handler( $option_group, $option_name, $sanitize_callback = '' ) {
 	_deprecated_function( __FUNCTION__, '3.0', 'unregister_setting()' );
-	return unregister_setting( $option_group, $option_name, $sanitize_callback );
+	unregister_setting( $option_group, $option_name, $sanitize_callback );
 }
 
 /**
@@ -210,7 +208,7 @@ function codepress_get_lang( $filename ) {
 }
 
 /**
- * Adds Javascript required to make CodePress work on the theme/plugin editors.
+ * Adds JavaScript required to make CodePress work on the theme/plugin editors.
  *
  * @since 2.8.0
  * @deprecated 3.0.0
@@ -276,7 +274,7 @@ function get_editable_authors( $user_id ) {
  *
  * @param int $user_id User ID.
  * @param bool $exclude_zeros Optional, default is true. Whether to exclude zeros.
- * @return unknown
+ * @return mixed
  */
 function get_editable_user_ids( $user_id, $exclude_zeros = true, $post_type = 'post' ) {
 	_deprecated_function( __FUNCTION__, '3.1', 'get_users()' );
@@ -336,7 +334,7 @@ class WP_User_Search {
 	 *
 	 * @since 2.1.0
 	 * @access private
-	 * @var unknown_type
+	 * @var mixed
 	 */
 	var $results;
 
@@ -345,7 +343,7 @@ class WP_User_Search {
 	 *
 	 * @since 2.1.0
 	 * @access private
-	 * @var unknown_type
+	 * @var string
 	 */
 	var $search_term;
 
@@ -390,7 +388,7 @@ class WP_User_Search {
 	 *
 	 * @since 2.1.0
 	 * @access private
-	 * @var unknown_type
+	 * @var int
 	 */
 	var $first_user;
 
@@ -462,7 +460,7 @@ class WP_User_Search {
 	 *
 	 * @since 2.1.0
 	 * @access private
-	 * @var unknown_type
+	 * @var WP_Error
 	 */
 	var $search_errors;
 
@@ -471,7 +469,7 @@ class WP_User_Search {
 	 *
 	 * @since 2.7.0
 	 * @access private
-	 * @var unknown_type
+	 * @var string
 	 */
 	var $paging_text;
 
@@ -609,7 +607,7 @@ class WP_User_Search {
 	 * @since 2.1.0
 	 * @access public
 	 *
-	 * @return unknown
+	 * @return array
 	 */
 	function get_results() {
 		return (array) $this->results;
@@ -852,42 +850,42 @@ function favorite_actions() {
 }
 
 function media_upload_image() {
-	__deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
+	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
 function media_upload_audio() {
-	__deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
+	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
 function media_upload_video() {
-	__deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
+	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
 function media_upload_file() {
-	__deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
+	_deprecated_function( __FUNCTION__, '3.3', 'wp_media_upload_handler()' );
 	return wp_media_upload_handler();
 }
 
 function type_url_form_image() {
-	__deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('image')" );
+	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('image')" );
 	return wp_media_insert_url_form( 'image' );
 }
 
 function type_url_form_audio() {
-	__deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('audio')" );
+	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('audio')" );
 	return wp_media_insert_url_form( 'audio' );
 }
 
 function type_url_form_video() {
-	__deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('video')" );
+	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('video')" );
 	return wp_media_insert_url_form( 'video' );
 }
 
 function type_url_form_file() {
-	__deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('file')" );
+	_deprecated_function( __FUNCTION__, '3.3', "wp_media_insert_url_form('file')" );
 	return wp_media_insert_url_form( 'file' );
 }
 
@@ -942,7 +940,7 @@ function get_allowed_themes() {
  * @since 1.5.0
  * @deprecated 3.4.0
  *
- * @return unknown
+ * @return array
  */
 function get_broken_themes() {
 	_deprecated_function( __FUNCTION__, '3.4', "wp_get_themes( array( 'errors' => true )" );
@@ -966,7 +964,7 @@ function get_broken_themes() {
  * @since 2.0.0
  * @deprecated 3.4.0
  *
- * @return unknown
+ * @return WP_Theme
  */
 function current_theme_info() {
 	_deprecated_function( __FUNCTION__, '3.4', 'wp_get_theme()' );
@@ -1070,7 +1068,7 @@ function wp_update_core($current, $feedback = '') {
 	if ( !empty($feedback) )
 		add_filter('update_feedback', $feedback);
 
-	include ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
+	include( ABSPATH . 'wp-admin/includes/class-wp-upgrader.php' );
 	$upgrader = new Core_Upgrader();
 	return $upgrader->upgrade($current);
 
@@ -1093,7 +1091,7 @@ function wp_update_plugin($plugin, $feedback = '') {
 	if ( !empty($feedback) )
 		add_filter('update_feedback', $feedback);
 
-	include ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
+	include( ABSPATH . 'wp-admin/includes/class-wp-upgrader.php' );
 	$upgrader = new Plugin_Upgrader();
 	return $upgrader->upgrade($plugin);
 }
@@ -1115,7 +1113,7 @@ function wp_update_theme($theme, $feedback = '') {
 	if ( !empty($feedback) )
 		add_filter('update_feedback', $feedback);
 
-	include ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
+	include( ABSPATH . 'wp-admin/includes/class-wp-upgrader.php' );
 	$upgrader = new Theme_Upgrader();
 	return $upgrader->upgrade($theme);
 }
@@ -1128,8 +1126,7 @@ function wp_update_theme($theme, $feedback = '') {
  * @since 2.0.0
  * @deprecated 3.7.0
  *
- * @param unknown_type $id
- * @return unknown
+ * @param int|bool $id
  */
 function the_attachment_links( $id = false ) {
 	_deprecated_function( __FUNCTION__, '3.7' );
@@ -1174,3 +1171,17 @@ function wp_dashboard_recent_comments_control() {}
 function wp_dashboard_secondary() {}
 function wp_dashboard_secondary_control() {}
 /**#@-*/
+
+/**
+ * This was once used to move child posts to a new parent.
+ *
+ * @since 2.3.0
+ * @deprecated 3.9.0
+ * @access private
+ *
+ * @param int $old_ID
+ * @param int $new_ID
+ */
+function _relocate_children( $old_ID, $new_ID ) {
+	_deprecated_function( __FUNCTION__, '3.9' );
+}
