@@ -16,7 +16,7 @@
  *
  * @package WordPress
  * @subpackage Plugin
- * @since 1.5
+ * @since 1.5.0
  */
 
 // Initialize the filter globals.
@@ -35,7 +35,7 @@ if ( ! isset( $wp_current_filter ) )
 	$wp_current_filter = array();
 
 /**
- * Hooks a function or method to a specific filter action.
+ * Hook a function or method to a specific filter action.
  *
  * WordPress offers filter hooks to allow plugins to modify
  * various types of internal data at runtime.
@@ -45,38 +45,37 @@ if ( ! isset( $wp_current_filter ) )
  * the opportunity to modify a value by returning a new value.
  *
  * The following example shows how a callback function is bound to a filter hook.
- * Note that $example is passed to the callback, (maybe) modified, then returned:
  *
- * <code>
- * function example_callback( $example ) {
- * 	// Maybe modify $example in some way
- * 	return $example;
- * }
- * add_filter( 'example_filter', 'example_callback' );
- * </code>
+ * Note that `$example` is passed to the callback, (maybe) modified, then returned:
+ *
+ *     function example_callback( $example ) {
+ *         // Maybe modify $example in some way.
+ *     	   return $example;
+ *     }
+ *     add_filter( 'example_filter', 'example_callback' );
  *
  * Since WordPress 1.5.1, bound callbacks can take as many arguments as are
- * passed as parameters in the corresponding apply_filters() call. The $accepted_args
+ * passed as parameters in the corresponding apply_filters() call. The `$accepted_args`
  * parameter allows for calling functions only when the number of args match.
  *
- * <strong>Note:</strong> the function will return true whether or not the callback
- * is valid. It is up to you to take care. This is done for optimization purposes,
+ * *Note:* the function will return true whether or not the callback is valid.
+ * It is up to you to take care. This is done for optimization purposes,
  * so everything is as quick as possible.
  *
- * @package WordPress
- * @subpackage Plugin
- *
- * @global array $wp_filter      A multidimensional array of all hooks and the callbacks hooked to them.
- * @global array $merged_filters Tracks the tags that need to be merged for later. If the hook is added, it doesn't need to run through that process.
- *
  * @since 0.71
  *
+ * @global array $wp_filter      A multidimensional array of all hooks and the callbacks hooked to them.
+ * @global array $merged_filters Tracks the tags that need to be merged for later. If the hook is added,
+ *                               it doesn't need to run through that process.
+ *
  * @param string   $tag             The name of the filter to hook the $function_to_add callback to.
  * @param callback $function_to_add The callback to be run when the filter is applied.
- * @param int      $priority        (optional) The order in which the functions associated with a particular action are executed. Lower numbers correspond with earlier execution, and functions with the same priority are executed in the order in which they were added to the action.
- *                                  Default 10.
- * @param int      $accepted_args   (optional) The number of arguments the function accepts.
- *                                  Default 1.
+ * @param int      $priority        Optional. Used to specify the order in which the functions
+ *                                  associated with a particular action are executed. Default 10.
+ *                                  Lower numbers correspond with earlier execution,
+ *                                  and functions with the same priority are executed
+ *                                  in the order in which they were added to the action.
+ * @param int      $accepted_args   Optional. The number of arguments the function accepts. Default 1.
  * @return boolean true
  */
 function add_filter( $tag, $function_to_add, $priority = 10, $accepted_args = 1 ) {
@@ -91,22 +90,40 @@ function add_filter( $tag, $function_to_add, $priority = 10, $accepted_args = 1
 /**
  * Check if any filter has been registered for a hook.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.5
- * @global array $wp_filter Stores all of the filters
+ * @since 2.5.0
  *
- * @param string $tag The name of the filter hook.
- * @param callback $function_to_check optional.
- * @return mixed If $function_to_check is omitted, returns boolean for whether the hook has anything registered.
- * 	When checking a specific function, the priority of that hook is returned, or false if the function is not attached.
- * 	When using the $function_to_check argument, this function may return a non-boolean value that evaluates to false
- * 	(e.g.) 0, so use the === operator for testing the return value.
+ * @global array $wp_filter Stores all of the filters.
+ *
+ * @param string        $tag               The name of the filter hook.
+ * @param callback|bool $function_to_check Optional. The callback to check for. Default false.
+ * @return bool|int If $function_to_check is omitted, returns boolean for whether the hook has
+ *                  anything registered. When checking a specific function, the priority of that
+ *                  hook is returned, or false if the function is not attached. When using the
+ *                  $function_to_check argument, this function may return a non-boolean value
+ *                  that evaluates to false (e.g.) 0, so use the === operator for testing the
+ *                  return value.
  */
 function has_filter($tag, $function_to_check = false) {
-	global $wp_filter;
+	// Don't reset the internal array pointer
+	$wp_filter = $GLOBALS['wp_filter'];
+
+	$has = ! empty( $wp_filter[ $tag ] );
+
+	// Make sure at least one priority has a filter callback
+	if ( $has ) {
+		$exists = false;
+		foreach ( $wp_filter[ $tag ] as $callbacks ) {
+			if ( ! empty( $callbacks ) ) {
+				$exists = true;
+				break;
+			}
+		}
+
+		if ( ! $exists ) {
+			$has = false;
+		}
+	}
 
-	$has = !empty($wp_filter[$tag]);
 	if ( false === $function_to_check || false == $has )
 		return $has;
 
@@ -130,34 +147,31 @@ function has_filter($tag, $function_to_check = false) {
  * the $tag parameter.
  *
  * The function allows for additional arguments to be added and passed to hooks.
- * <code>
- * // Our filter callback function
- * function example_callback( $string, $arg1, $arg2 ) {
- *	// (maybe) modify $string
- *	return $string;
- * }
- * add_filter( 'example_filter', 'example_callback', 10, 3 );
  *
- * // Apply the filters by calling the 'example_callback' function we
- * // "hooked" to 'example_filter' using the add_filter() function above.
- * // - 'example_filter' is the filter hook $tag
- * // - 'filter me' is the value being filtered
- * // - $arg1 and $arg2 are the additional arguments passed to the callback.
- * $value = apply_filters( 'example_filter', 'filter me', $arg1, $arg2 );
- * </code>
+ *     // Our filter callback function
+ *     function example_callback( $string, $arg1, $arg2 ) {
+ *         // (maybe) modify $string
+ *         return $string;
+ *     }
+ *     add_filter( 'example_filter', 'example_callback', 10, 3 );
  *
- * @package WordPress
- * @subpackage Plugin
- *
- * @global array $wp_filter         Stores all of the filters
- * @global array $merged_filters    Merges the filter hooks using this function.
- * @global array $wp_current_filter stores the list of current filters with the current one last
+ *     /*
+ *      * Apply the filters by calling the 'example_callback' function we
+ *      * "hooked" to 'example_filter' using the add_filter() function above.
+ *      * - 'example_filter' is the filter hook $tag
+ *      * - 'filter me' is the value being filtered
+ *      * - $arg1 and $arg2 are the additional arguments passed to the callback.
+ *     $value = apply_filters( 'example_filter', 'filter me', $arg1, $arg2 );
  *
  * @since 0.71
  *
- * @param string $tag  The name of the filter hook.
- * @param mixed $value The value on which the filters hooked to <tt>$tag</tt> are applied on.
- * @param mixed $var   Additional variables passed to the functions hooked to <tt>$tag</tt>.
+ * @global array $wp_filter         Stores all of the filters.
+ * @global array $merged_filters    Merges the filter hooks using this function.
+ * @global array $wp_current_filter Stores the list of current filters with the current one last.
+ *
+ * @param string $tag   The name of the filter hook.
+ * @param mixed  $value The value on which the filters hooked to `$tag` are applied on.
+ * @param mixed  $var   Additional variables passed to the functions hooked to `$tag`.
  * @return mixed The filtered value after all hooked functions are applied to it.
  */
 function apply_filters( $tag, $value ) {
@@ -165,7 +179,7 @@ function apply_filters( $tag, $value ) {
 
 	$args = array();
 
-	// Do 'all' actions first
+	// Do 'all' actions first.
 	if ( isset($wp_filter['all']) ) {
 		$wp_current_filter[] = $tag;
 		$args = func_get_args();
@@ -181,7 +195,7 @@ function apply_filters( $tag, $value ) {
 	if ( !isset($wp_filter['all']) )
 		$wp_current_filter[] = $tag;
 
-	// Sort
+	// Sort.
 	if ( !isset( $merged_filters[ $tag ] ) ) {
 		ksort($wp_filter[$tag]);
 		$merged_filters[ $tag ] = true;
@@ -209,18 +223,17 @@ function apply_filters( $tag, $value ) {
 /**
  * Execute functions hooked on a specific filter hook, specifying arguments in an array.
  *
+ * @see 3.0.0
+ *
  * @see apply_filters() This function is identical, but the arguments passed to the
- * functions hooked to <tt>$tag</tt> are supplied using an array.
+ * functions hooked to `$tag` are supplied using an array.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 3.0.0
- * @global array $wp_filter Stores all of the filters
- * @global array $merged_filters Merges the filter hooks using this function.
- * @global array $wp_current_filter stores the list of current filters with the current one last
+ * @global array $wp_filter         Stores all of the filters
+ * @global array $merged_filters    Merges the filter hooks using this function.
+ * @global array $wp_current_filter Stores the list of current filters with the current one last
  *
- * @param string $tag The name of the filter hook.
- * @param array $args The arguments supplied to the functions hooked to <tt>$tag</tt>
+ * @param string $tag  The name of the filter hook.
+ * @param array  $args The arguments supplied to the functions hooked to $tag.
  * @return mixed The filtered value after all hooked functions are applied to it.
  */
 function apply_filters_ref_array($tag, $args) {
@@ -273,26 +286,27 @@ function apply_filters_ref_array($tag, $args) {
  * when the hook was added. This goes for both filters and actions. No warning
  * will be given on removal failure.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 1.2
+ * @since 1.2.0
  *
- * @param string $tag The filter hook to which the function to be removed is hooked.
+ * @param string   $tag                The filter hook to which the function to be removed is hooked.
  * @param callback $function_to_remove The name of the function which should be removed.
- * @param int $priority optional. The priority of the function (default: 10).
- * @param int $accepted_args optional. The number of arguments the function accepts (default: 1).
+ * @param int      $priority           Optional. The priority of the function. Default 10.
  * @return boolean Whether the function existed before it was removed.
  */
 function remove_filter( $tag, $function_to_remove, $priority = 10 ) {
-	$function_to_remove = _wp_filter_build_unique_id($tag, $function_to_remove, $priority);
+	$function_to_remove = _wp_filter_build_unique_id( $tag, $function_to_remove, $priority );
 
-	$r = isset($GLOBALS['wp_filter'][$tag][$priority][$function_to_remove]);
+	$r = isset( $GLOBALS['wp_filter'][ $tag ][ $priority ][ $function_to_remove ] );
 
-	if ( true === $r) {
-		unset($GLOBALS['wp_filter'][$tag][$priority][$function_to_remove]);
-		if ( empty($GLOBALS['wp_filter'][$tag][$priority]) )
-			unset($GLOBALS['wp_filter'][$tag][$priority]);
-		unset($GLOBALS['merged_filters'][$tag]);
+	if ( true === $r ) {
+		unset( $GLOBALS['wp_filter'][ $tag ][ $priority ][ $function_to_remove ] );
+		if ( empty( $GLOBALS['wp_filter'][ $tag ][ $priority ] ) ) {
+			unset( $GLOBALS['wp_filter'][ $tag ][ $priority ] );
+		}
+		if ( empty( $GLOBALS['wp_filter'][ $tag ] ) ) {
+			$GLOBALS['wp_filter'][ $tag ] = array();
+		}
+		unset( $GLOBALS['merged_filters'][ $tag ] );
 	}
 
 	return $r;
@@ -301,24 +315,26 @@ function remove_filter( $tag, $function_to_remove, $priority = 10 ) {
 /**
  * Remove all of the hooks from a filter.
  *
- * @since 2.7
+ * @since 2.7.0
  *
- * @param string $tag The filter to remove hooks from.
- * @param int $priority The priority number to remove.
+ * @param string   $tag      The filter to remove hooks from.
+ * @param int|bool $priority Optional. The priority number to remove. Default false.
  * @return bool True when finished.
  */
-function remove_all_filters($tag, $priority = false) {
+function remove_all_filters( $tag, $priority = false ) {
 	global $wp_filter, $merged_filters;
 
-	if( isset($wp_filter[$tag]) ) {
-		if( false !== $priority && isset($wp_filter[$tag][$priority]) )
-			unset($wp_filter[$tag][$priority]);
-		else
-			unset($wp_filter[$tag]);
+	if ( isset( $wp_filter[ $tag ]) ) {
+		if ( false !== $priority && isset( $wp_filter[ $tag ][ $priority ] ) ) {
+			$wp_filter[ $tag ][ $priority ] = array();
+		} else {
+			$wp_filter[ $tag ] = array();
+		}
 	}
 
-	if( isset($merged_filters[$tag]) )
-		unset($merged_filters[$tag]);
+	if ( isset( $merged_filters[ $tag ] ) ) {
+		unset( $merged_filters[ $tag ] );
+	}
 
 	return true;
 }
@@ -326,9 +342,7 @@ function remove_all_filters($tag, $priority = false) {
 /**
  * Retrieve the name of the current filter or action.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.5
+ * @since 2.5.0
  *
  * @return string Hook name of the current filter or action.
  */
@@ -337,6 +351,61 @@ function current_filter() {
 	return end( $wp_current_filter );
 }
 
+/**
+ * Retrieve the name of the current action.
+ *
+ * @since 3.9.0
+ *
+ * @return string Hook name of the current action.
+ */
+function current_action() {
+	return current_filter();
+}
+
+/**
+ * Retrieve the name of a filter currently being processed.
+ *
+ * The function current_filter() only returns the most recent filter or action
+ * being executed. did_action() returns true once the action is initially
+ * processed.
+ *
+ * This function allows detection for any filter currently being
+ * executed (despite not being the most recent filter to fire, in the case of
+ * hooks called from hook callbacks) to be verified.
+ *
+ * @since 3.9.0
+ *
+ * @see current_filter()
+ * @see did_action()
+ * @global array $wp_current_filter Current filter.
+ *
+ * @param null|string $filter Optional. Filter to check. Defaults to null, which
+ *                            checks if any filter is currently being run.
+ * @return bool Whether the filter is currently in the stack.
+ */
+function doing_filter( $filter = null ) {
+	global $wp_current_filter;
+
+	if ( null === $filter ) {
+		return ! empty( $wp_current_filter );
+	}
+
+	return in_array( $filter, $wp_current_filter );
+}
+
+/**
+ * Retrieve the name of an action currently being processed.
+ *
+ * @since 3.9.0
+ *
+ * @param string|null $action Optional. Action to check. Defaults to null, which checks
+ *                            if any action is currently being run.
+ * @return bool Whether the action is currently in the stack.
+ */
+function doing_action( $action = null ) {
+	return doing_filter( $action );
+}
+
 /**
  * Hooks a function on to a specific action.
  *
@@ -345,16 +414,17 @@ function current_filter() {
  * one or more of its PHP functions are executed at these points, using the
  * Action API.
  *
- * @uses add_filter() Adds an action. Parameter list and functionality are the same.
+ * @since 1.2.0
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 1.2
- *
- * @param string $tag The name of the action to which the $function_to_add is hooked.
+ * @param string   $tag             The name of the action to which the $function_to_add is hooked.
  * @param callback $function_to_add The name of the function you wish to be called.
- * @param int $priority optional. Used to specify the order in which the functions associated with a particular action are executed (default: 10). Lower numbers correspond with earlier execution, and functions with the same priority are executed in the order in which they were added to the action.
- * @param int $accepted_args optional. The number of arguments the function accept (default 1).
+ * @param int      $priority        Optional. Used to specify the order in which the functions
+ *                                  associated with a particular action are executed. Default 10.
+ *                                  Lower numbers correspond with earlier execution,
+ *                                  and functions with the same priority are executed
+ *                                  in the order in which they were added to the action.
+ * @param int      $accepted_args   Optional. The number of arguments the function accept. Default 1.
+ * @return bool Will always return true.
  */
 function add_action($tag, $function_to_add, $priority = 10, $accepted_args = 1) {
 	return add_filter($tag, $function_to_add, $priority, $accepted_args);
@@ -363,25 +433,22 @@ function add_action($tag, $function_to_add, $priority = 10, $accepted_args = 1)
 /**
  * Execute functions hooked on a specific action hook.
  *
- * This function invokes all functions attached to action hook $tag. It is
+ * This function invokes all functions attached to action hook `$tag`. It is
  * possible to create new action hooks by simply calling this function,
- * specifying the name of the new hook using the <tt>$tag</tt> parameter.
+ * specifying the name of the new hook using the `$tag` parameter.
  *
  * You can pass extra arguments to the hooks, much like you can with
- * apply_filters().
+ * {@see apply_filters()}.
  *
- * @see apply_filters() This function works similar with the exception that
- * nothing is returned and only the functions or methods are called.
+ * @since 1.2.0
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 1.2
- * @global array $wp_filter Stores all of the filters
+ * @global array $wp_filter  Stores all of the filters
  * @global array $wp_actions Increments the amount of times action was triggered.
  *
  * @param string $tag The name of the action to be executed.
- * @param mixed $arg,... Optional additional arguments which are passed on to the functions hooked to the action.
- * @return null Will return null if $tag does not exist in $wp_filter array
+ * @param mixed  $arg Optional. Additional arguments which are passed on to the
+ *                    functions hooked to the action. Default empty.
+ * @return null Will return null if $tag does not exist in $wp_filter array.
  */
 function do_action($tag, $arg = '') {
 	global $wp_filter, $wp_actions, $merged_filters, $wp_current_filter;
@@ -436,13 +503,12 @@ function do_action($tag, $arg = '') {
 /**
  * Retrieve the number of times an action is fired.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.1
+ * @since 2.1.0
+ *
  * @global array $wp_actions Increments the amount of times action was triggered.
  *
  * @param string $tag The name of the action hook.
- * @return int The number of times action hook <tt>$tag</tt> is fired
+ * @return int The number of times action hook $tag is fired.
  */
 function did_action($tag) {
 	global $wp_actions;
@@ -456,18 +522,16 @@ function did_action($tag) {
 /**
  * Execute functions hooked on a specific action hook, specifying arguments in an array.
  *
- * @see do_action() This function is identical, but the arguments passed to the
- * functions hooked to <tt>$tag</tt> are supplied using an array.
+ * @since 2.1.0
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.1
- * @global array $wp_filter Stores all of the filters
+ * @see do_action() This function is identical, but the arguments passed to the
+ *                  functions hooked to $tag< are supplied using an array.
+ * @global array $wp_filter  Stores all of the filters
  * @global array $wp_actions Increments the amount of times action was triggered.
  *
- * @param string $tag The name of the action to be executed.
- * @param array $args The arguments supplied to the functions hooked to <tt>$tag</tt>
- * @return null Will return null if $tag does not exist in $wp_filter array
+ * @param string $tag  The name of the action to be executed.
+ * @param array  $args The arguments supplied to the functions hooked to `$tag`.
+ * @return null Will return null if `$tag` does not exist in `$wp_filter` array.
  */
 function do_action_ref_array($tag, $args) {
 	global $wp_filter, $wp_actions, $merged_filters, $wp_current_filter;
@@ -514,17 +578,18 @@ function do_action_ref_array($tag, $args) {
 /**
  * Check if any action has been registered for a hook.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.5
+ * @since 2.5.0
+ *
  * @see has_filter() has_action() is an alias of has_filter().
  *
- * @param string $tag The name of the action hook.
- * @param callback $function_to_check optional.
- * @return mixed If $function_to_check is omitted, returns boolean for whether the hook has anything registered.
- * 	When checking a specific function, the priority of that hook is returned, or false if the function is not attached.
- * 	When using the $function_to_check argument, this function may return a non-boolean value that evaluates to false
- * 	(e.g.) 0, so use the === operator for testing the return value.
+ * @param string        $tag               The name of the action hook.
+ * @param callback|bool $function_to_check Optional. The callback to check for. Default false.
+ * @return bool|int If $function_to_check is omitted, returns boolean for whether the hook has
+ *                  anything registered. When checking a specific function, the priority of that
+ *                  hook is returned, or false if the function is not attached. When using the
+ *                  $function_to_check argument, this function may return a non-boolean value
+ *                  that evaluates to false (e.g.) 0, so use the === operator for testing the
+ *                  return value.
  */
 function has_action($tag, $function_to_check = false) {
 	return has_filter($tag, $function_to_check);
@@ -537,13 +602,11 @@ function has_action($tag, $function_to_check = false) {
  * method can be used to remove default functions attached to a specific filter
  * hook and possibly replace them with a substitute.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 1.2
+ * @since 1.2.0
  *
- * @param string $tag The action hook to which the function to be removed is hooked.
+ * @param string   $tag                The action hook to which the function to be removed is hooked.
  * @param callback $function_to_remove The name of the function which should be removed.
- * @param int $priority optional The priority of the function (default: 10).
+ * @param int      $priority           Optional. The priority of the function. Default 10.
  * @return boolean Whether the function is removed.
  */
 function remove_action( $tag, $function_to_remove, $priority = 10 ) {
@@ -553,10 +616,10 @@ function remove_action( $tag, $function_to_remove, $priority = 10 ) {
 /**
  * Remove all of the hooks from an action.
  *
- * @since 2.7
+ * @since 2.7.0
  *
- * @param string $tag The action to remove hooks from.
- * @param int $priority The priority number to remove them from.
+ * @param string   $tag      The action to remove hooks from.
+ * @param int|bool $priority The priority number to remove them from. Default false.
  * @return bool True when finished.
  */
 function remove_all_actions($tag, $priority = false) {
@@ -572,49 +635,84 @@ function remove_all_actions($tag, $priority = false) {
  *
  * This method extracts the name of a plugin from its filename.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 1.5
- *
- * @access private
+ * @since 1.5.0
  *
  * @param string $file The filename of plugin.
  * @return string The name of a plugin.
- * @uses WP_PLUGIN_DIR
  */
-function plugin_basename($file) {
-	$file = str_replace('\\','/',$file); // sanitize for Win32 installs
-	$file = preg_replace('|/+|','/', $file); // remove any duplicate slash
-	$plugin_dir = str_replace('\\','/',WP_PLUGIN_DIR); // sanitize for Win32 installs
-	$plugin_dir = preg_replace('|/+|','/', $plugin_dir); // remove any duplicate slash
-	$mu_plugin_dir = str_replace('\\','/',WPMU_PLUGIN_DIR); // sanitize for Win32 installs
-	$mu_plugin_dir = preg_replace('|/+|','/', $mu_plugin_dir); // remove any duplicate slash
+function plugin_basename( $file ) {
+	global $wp_plugin_paths;
+
+	foreach ( $wp_plugin_paths as $dir => $realdir ) {
+		if ( strpos( $file, $realdir ) === 0 ) {
+			$file = $dir . substr( $file, strlen( $realdir ) );
+		}
+	}
+
+	$file = wp_normalize_path( $file );
+	$plugin_dir = wp_normalize_path( WP_PLUGIN_DIR );
+	$mu_plugin_dir = wp_normalize_path( WPMU_PLUGIN_DIR );
+
 	$file = preg_replace('#^' . preg_quote($plugin_dir, '#') . '/|^' . preg_quote($mu_plugin_dir, '#') . '/#','',$file); // get relative path from plugins dir
 	$file = trim($file, '/');
 	return $file;
 }
 
 /**
- * Gets the filesystem directory path (with trailing slash) for the plugin __FILE__ passed in
- * @package WordPress
- * @subpackage Plugin
- * @since 2.8
+ * Register a plugin's real path.
  *
- * @param string $file The filename of the plugin (__FILE__)
- * @return string the filesystem path of the directory that contains the plugin
+ * This is used in plugin_basename() to resolve symlinked paths.
+ *
+ * @since 3.9.0
+ *
+ * @see plugin_basename()
+ *
+ * @param string $file Known path to the file.
+ * @return bool Whether the path was able to be registered.
+ */
+function wp_register_plugin_realpath( $file ) {
+	global $wp_plugin_paths;
+
+	// Normalize, but store as static to avoid recalculation of a constant value
+	static $wp_plugin_path, $wpmu_plugin_path;
+	if ( ! isset( $wp_plugin_path ) ) {
+		$wp_plugin_path   = wp_normalize_path( WP_PLUGIN_DIR   );
+		$wpmu_plugin_path = wp_normalize_path( WPMU_PLUGIN_DIR );
+	}
+
+	$plugin_path = wp_normalize_path( dirname( $file ) );
+	$plugin_realpath = wp_normalize_path( dirname( realpath( $file ) ) );
+
+	if ( $plugin_path === $wp_plugin_path || $plugin_path === $wpmu_plugin_path ) {
+		return false;
+	}
+
+	if ( $plugin_path !== $plugin_realpath ) {
+		$wp_plugin_paths[ $plugin_path ] = $plugin_realpath;
+	}
+
+	return true;
+}
+
+/**
+ * Get the filesystem directory path (with trailing slash) for the plugin __FILE__ passed in.
+ *
+ * @since 2.8.0
+ *
+ * @param string $file The filename of the plugin (__FILE__).
+ * @return string the filesystem path of the directory that contains the plugin.
  */
 function plugin_dir_path( $file ) {
 	return trailingslashit( dirname( $file ) );
 }
 
 /**
- * Gets the URL directory path (with trailing slash) for the plugin __FILE__ passed in
- * @package WordPress
- * @subpackage Plugin
- * @since 2.8
+ * Get the URL directory path (with trailing slash) for the plugin __FILE__ passed in.
  *
- * @param string $file The filename of the plugin (__FILE__)
- * @return string the URL path of the directory that contains the plugin
+ * @since 2.8.0
+ *
+ * @param string $file The filename of the plugin (__FILE__).
+ * @return string the URL path of the directory that contains the plugin.
  */
 function plugin_dir_url( $file ) {
 	return trailingslashit( plugins_url( '', $file ) );
@@ -633,12 +731,10 @@ function plugin_dir_url( $file ) {
  * wp-content/plugins/sample.php the name of this hook will be
  * 'activate_sample.php'.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.0
+ * @since 2.0.0
  *
- * @param string $file The filename of the plugin including the path.
- * @param callback $function the function hooked to the 'activate_PLUGIN' action.
+ * @param string   $file     The filename of the plugin including the path.
+ * @param callback $function The function hooked to the 'activate_PLUGIN' action.
  */
 function register_activation_hook($file, $function) {
 	$file = plugin_basename($file);
@@ -658,12 +754,10 @@ function register_activation_hook($file, $function) {
  * wp-content/plugins/sample.php the name of this hook will be
  * 'deactivate_sample.php'.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.0
+ * @since 2.0.0
  *
- * @param string $file The filename of the plugin including the path.
- * @param callback $function the function hooked to the 'deactivate_PLUGIN' action.
+ * @param string   $file     The filename of the plugin including the path.
+ * @param callback $function The function hooked to the 'deactivate_PLUGIN' action.
  */
 function register_deactivation_hook($file, $function) {
 	$file = plugin_basename($file);
@@ -690,10 +784,11 @@ function register_deactivation_hook($file, $function) {
  * should always check for the 'WP_UNINSTALL_PLUGIN' constant, before
  * executing.
  *
- * @since 2.7
+ * @since 2.7.0
  *
- * @param string $file
- * @param callback $callback The callback to run when the hook is called. Must be a static method or function.
+ * @param string   $file     Plugin file.
+ * @param callback $callback The callback to run when the hook is called. Must be
+ *                           a static method or function.
  */
 function register_uninstall_hook( $file, $callback ) {
 	if ( is_array( $callback ) && is_object( $callback[0] ) ) {
@@ -701,16 +796,19 @@ function register_uninstall_hook( $file, $callback ) {
 		return;
 	}
 
-	// The option should not be autoloaded, because it is not needed in most
-	// cases. Emphasis should be put on using the 'uninstall.php' way of
-	// uninstalling the plugin.
+	/*
+	 * The option should not be autoloaded, because it is not needed in most
+	 * cases. Emphasis should be put on using the 'uninstall.php' way of
+	 * uninstalling the plugin.
+	 */
 	$uninstallable_plugins = (array) get_option('uninstall_plugins');
 	$uninstallable_plugins[plugin_basename($file)] = $callback;
+
 	update_option('uninstall_plugins', $uninstallable_plugins);
 }
 
 /**
- * Calls the 'all' hook, which will process the functions hooked into it.
+ * Call the 'all' hook, which will process the functions hooked into it.
  *
  * The 'all' hook passes all of the arguments or parameters that were used for
  * the hook, which this function was called for.
@@ -720,13 +818,9 @@ function register_uninstall_hook( $file, $callback ) {
  * functions. This function does not check for the existence of the all hook, so
  * it will fail unless the all hook exists prior to this function call.
  *
- * @package WordPress
- * @subpackage Plugin
- * @since 2.5
+ * @since 2.5.0
  * @access private
  *
- * @uses $wp_filter Used to process all of the functions in the 'all' hook
- *
  * @param array $args The collected parameters from the hook that was called.
  */
 function _wp_call_all_hook($args) {
@@ -758,17 +852,21 @@ function _wp_call_all_hook($args) {
  * Functions and static method callbacks are just returned as strings and
  * shouldn't have any speed penalty.
  *
- * @package WordPress
- * @subpackage Plugin
- * @access private
- * @since 2.2.3
- * @link http://trac.wordpress.org/ticket/3875
+ * @link https://core.trac.wordpress.org/ticket/3875
  *
- * @global array $wp_filter Storage for all of the filters and actions
- * @param string $tag Used in counting how many hooks were applied
+ * @since 2.2.3
+ * @access private
+ *
+ * @global array $wp_filter Storage for all of the filters and actions.
+ *
+ * @param string   $tag      Used in counting how many hooks were applied
  * @param callback $function Used for creating unique id
- * @param int|bool $priority Used in counting how many hooks were applied. If === false and $function is an object reference, we return the unique id only if it already has one, false otherwise.
- * @return string|bool Unique ID for usage as array key or false if $priority === false and $function is an object reference, and it does not already have a unique id.
+ * @param int|bool $priority Used in counting how many hooks were applied. If === false
+ *                           and $function is an object reference, we return the unique
+ *                           id only if it already has one, false otherwise.
+ * @return string|bool Unique ID for usage as array key or false if $priority === false
+ *                     and $function is an object reference, and it does not already have
+ *                     a unique id.
  */
 function _wp_filter_build_unique_id($tag, $function, $priority) {
 	global $wp_filter;
